@@ -54,17 +54,26 @@ class random_timeout:
             timeout_in_days = round(timeout_in_seconds / 86400) # Convert sleep time in seconds to days
             til = datetime.now() + timedelta(days=timeout_in_days)
             til = til.strftime('%A, %B %e')
-            print('Sleeping', timeout_in_days, 'days until', til)
+            if timeout_in_days == 1:
+                printr('Sleeping 1 day until', til)
+            else:
+                printr('Sleeping', timeout_in_days, 'days until', til)
         elif from_hours or timeout_in_seconds > 3600:
             timeout_in_hours = round(timeout_in_seconds / 3600) # Convert sleep time in seconds to hours
             til = datetime.now() + timedelta(hours=timeout_in_hours)
             til = til.strftime('%H:%M')
-            print('Sleeping', timeout_in_hours, 'hours until', til)
+            if timeout_in_hours == 1:
+                printr('Sleeping 1 hour until', til)
+            else:
+                printr('Sleeping', timeout_in_hours, 'hours until', til)
         elif timeout_in_seconds >= 60 or from_minutes:
             timeout_in_minutes = round(timeout_in_seconds / 60) # Convert sleep time in seconds to minutes
             til = datetime.now() + timedelta(minutes=timeout_in_minutes)
             til = til.strftime('%H:%M')
-            print('Sleeping', timeout_in_minutes, 'minutes until', til)
+            if timeout_in_hours == 1:
+                printr('Sleeping 1 minute until', til)
+            else:
+                printr('Sleeping', timeout_in_minutes, 'minutes until', til)
 
         sleep(timeout_in_seconds)
 
@@ -72,23 +81,35 @@ class sleep_for:
     '''Sleep amount of time in minutes, hours or days and prints when it will continue'''
     def __init__(self, seconds=None, minutes=None, hours=None, days=None):
         if seconds:
-            printr('Sleeping', seconds, 'seconds', level='debug')
+            if seconds == 1:
+                printr('Sleeping 1 second')
+            else:
+                printr('Sleeping', seconds, 'seconds', level='debug')
             sleep(seconds)
         if minutes:
             til = datetime.now() + timedelta(minutes=minutes)
             til = til.strftime('%H:%M')
-            print('Sleeping', minutes, 'minutes until', til)
-            print()
+            if minutes == 1:
+                printr('Sleeping 1 minute until', til)
+            else:
+                printr('Sleeping', minutes, 'minutes until', til)
+            printr()
             sleep(minutes * 60)
         elif hours:
             til = datetime.now() + timedelta(hours=hours)
             til = til.strftime('%H:%M')
-            print('Sleeping', hours, 'hours until', til)
-            print()
+            if hours == 1:
+                printr('Sleeping 1 hour until', til)
+            else:
+                printr('Sleeping', hours, 'hours until', til)
+            printr()
             sleep(hours * 3600)
-        else:
+        elif days:
             til = datetime.now() + timedelta(days=days)
             til = til.strftime('%A, %B %e')
-            print('Sleeping', days, 'days until', til)
+            if days == 1:
+                printr('Sleeping 1 day until', til)
+            else:
+                printr('Sleeping', days, 'days until', til)
             printr()
             sleep(days * 86400)
\ No newline at end of file
